% Transfer Function Interpreter.
% Version 3.1  20-Jan-1998
% Copyright (c) 1994 by Zanichelli, Bologna, Italy
%
% NOTE: the Intp Toolbox does not require the Control System Toolbox.
%
% Used notations:
% (TFI) Functions accessible from the Transfer Function Interpreter;
% (MTL) Functions accessible only from Matlab.
%
% LIST OF THE FUNCTIONS ACCESSIBLE FROM THE TFI ENVIRONMENT
%
%    con[vert],gc,gd : continuous-to-discrete-time conversion
%    defa[ctf],gi,gj : defactorization of a transfer function
%    deft[f],gi : definition of special transfer functions
%    delf : elimination of all the figures
%    des[crf] : describing function analysis
%    fac[tf],gi,gj : factorization of a transfer function
%    fre[sp],gi : frequency response (six options)
%    gpm[arg],gi : gain and phase margins
%    inv[tr],gi : inverse Laplace (or Z-) transform
%    lag[c],gi,gj : lag compensator
%    lea[dc],gi,gj : lead compensator
%    mak[eleg]: creates or cleans a legend
%    nls[im],gi,gj,gk : nonlinear system simulation
%    ord[f] : ordering of all the figures
%    per[ftra],gi,gj,gk,gw : digital perfect tracking compensator
%    pidc,gi,gj : continuous-time PID controller
%    pidd,gi,gj : discrete-time PID controller
%    pidn[ich] : PD, PI, and PID regulator design with the Nichols diagram
%    regd[ph],gi,gj,gk,gw : pole assignment with the Diophantine equation
%    regn[ich] : lag and lead compensator design with the Nichols diagram
%    regr[ootl]: compensator design with root locus
%    res[figlo]: resets the figure locations to the default
%    rob[par],gi,gj,gk,[gw] : parametric robustness check
%    roo[tl],gi : root locus
%    rou[th],gi : routh stability intervals
%    sam[ptime],T : definition of work sampling time
%    sel[ect],gi,gj : selection of factors of a transfer function
%    sta[rtint] : definition of some TFI environment parameters
%    tfe[val],gi : evaluation of a transfer function
%    tre[sp],gi : time response (four options)
%    wpl[ane],gi,gj : w-plane conversion
%    zpp[lots],gi[,gj,gk,gw] : zero-pole layout
%
% Square brackets denote an optional part of the call string.
%
% COMPLETE LIST OF THE INTP TOOLBOX FUNCTIONS
%
% Interface:
%   exportf    - Converts TFI to Matlab representation (MTL).
%   importf    - Converts Matlab to TFI representation (MTL).
%   exportf1   - Converts TFI to LTI systems representation (MTL).
%   importf1   - Converts LTI systems to TFI representation (MTL).
%
% Transfer functions:
%   defactf    - De-factorizes a transfer function (TFI).
%   factf      - Factorizes a transfer function (TFI).
%   invtr      - Inverse transform, Laplace or Z (TFI).
%   select     - Selects factors from a transfer function (TFI).
%   tfeval     - Evaluates a transfer function (TFI).
%   zpplots    - Plots the zero-pole map of transfer functions (TFI).
%
% Generation of special transfer functions:
%   deftf      - Any z/p map with mouse or Bessel, Butterworth, Pade' (TFI).
%
% Time response:
%   tresp      - Time response, interactive (TFI).
%
% Frequency response:
%   fresp      - Frequency response, interactive (TFI).
%   gpmarg     - Generalized gain and phase margins (TFI).
%
% Root locus
%   rootl      - Root locus, interactive (TFI).
%
% Conversion from continuous-time to discrete-time and vice versa:
%   convert    - Continuous to discrete-time conversion (TFI).
%   wplane     - w-plane direct and inverse conversion (TFI).
%
% Routh stability criterion:
%   routh      - Stability intervals with Routh criterion (TFI).
%
% Compensator and regulator synthesis:
%   lagc       - Lag compensator synthesis (TFI and MTL).
%   leadc      - Lead compensator synthesis (TFI and MTL).
%   perftra    - Preaction unit for digital perfect tracking (TFI and MTL).
%   pidc       - PID regulator (TFI and MTL).
%   pidd       - Discrete-time PID regulator (TFI and MTL).
%   pidnich    - Regulator synthesis according Nichols (TFI and MTL).
%   regdph     - Regulator with the Diophantine equation (TFI and MTL).
%   regnich    - Compensator synthesis according Nichols (TFI and MTL).
%   regrootl   - Compensator synthesis with thew root locus (TFI and MTL).
%
% Nonlinear system analysis:
%   descrf     - Describing function analysis (TFI).
%   nlsim      - Simulation of a nonlinear feedback system (TFI).
%
% Robustness analysis:
%   robpar     - Parametric robustness analysis (TFI).
%
% Change of TFI settings:
%   samptime   - Displays and/or changes the current sampling time (TFI).
%   startint   - Changes some TFI settings: work dir., path, legend (TFI).
%
% Utilities (MTL):
%   asymga     - Asymptotic approximation of the Bode gain diagram.
%   asymph     - Asymptotic approximation of the Bode phase diagram.
%   bodec      - Bode diagrams in one figure, continuous-time.
%   boded      - Bode diagrams in one figure, discrete-time.
%   cobin      - Binomial coefficient.
%   cvtxz      - Continuous to discrete-time conversion.
%   dezpk      - Builds a transfer function from zeros, poles and gain.
%   diopha     - Solves the Diophantine equation.
%   diwplane   - w-plane direct conversion.
%   drgrid     - Constant damping curves, discrete-time.
%   expgm      - Power of a transfer function.
%   fact       - Factorial of an integer number.
%   fbessel    - Bessel filter transfer function.
%   fbutter    - Butterworth filter transfer function.
%   fpade      - Pade' delay transfer function.
%   frespc     - Frequency response, continuous-time, non-interactive.
%   frespd     - Frequency response, discrete-time, non-interactive.
%   invtrc     - Inverse Laplace transform.
%   invtrd     - Inverse Z transform.
%   inwplane   - w-plane inverse conversion.
%   jorcf      - Builds the real Jordan form of a transfer function.
%   makeleg    - Crates or cleans a legend (TFI and MTL).
%   nigrid     - Constant M and N loci for Nichols plots.
%   nygrid     - Constant M and N loci for Nyquist plots.
%   prodgm     - Product/quotient of two transfer functions.
%   rgrid      - Constant damping curves, continuous-time.
%   rootlc     - Root locus, continuous-time, non-interactive.
%   rootld     - Root locus, discrete-time, non-interactive.
%   routhc     - Routh stability intervals for continuous-time systems.
%   routhd     - Routh stability intervals for discrete-time systems.
%   sumgm      - Sum/difference of two transfer functions.
%   tfg        - Displays a transfer function in TFI form.
%   tfg1       - Displays a parametric transfer function in TFI form.
%   tfm        - Displays a transfer function in Matlab form.
%   trespc     - Time response, continuous-time, non-interactive.
%   trespd     - Time response, discrete-time, non-interactive.
%   tozpk      - Derives zeros, poles and gain from a transfer function.
